function [t, y] = solve_heun(f, tBereich, y0, h)
% Integration der DGL
%    y' = f(y, t)
% mit dem Heun-Verfahren.
%   Argumente
%       Funktion f
%       Zeitintervall [tStart tEnd]
%       Startwerte y(0) = y0 (Vektor!)
%       Schrittweite h
%   Ergebnis
%     Spaltenvektor t mit Zeitwerten
%     Matrix y mit Spaltenvektoren y(t,i) mit Naeherungsloesung yi(t)
%         der i-ten Komponente
  dim = size(y0, 2);         % Dimension von y (und von f!)
  t0 = tBereich(1);          % Anfangszeit
  t1 = tBereich(2);          % Endzeit
  N = ceil((t1 - t0)/h) + 1; % Zahl der Zeitpunkte
  y = zeros(N,dim);          % Vektoren fuer die Loesung
  t = zeros(N,1);
  y(1,:) = y0;
  t(1) = t0;
  for I = 2:N
    k1 = f(t(I-1), y(I-1,:))';
    k2 = f(t(I-1) + h, y(I-1,:) + h*k1)';
    y(I,:) = y(I-1,:) + 0.5*h*(k1 + k2);
    t(I) = t(I-1) + h;
  end
end
